Learn R Programming

ALLSPICER (version 0.1.9)

get_af_mat: get_af_mat

Description

simulation function: compute allele frequency information variants with allele counts stored in diagonal matrix `AC` from a population of sample size `n_ind`

Usage

get_af_mat(AC, n_ind)

Value

A `n_var`x`n_var` diagnal matrix of allele frequency information for `n_var` (dimension of `AC`) variants

Arguments

AC

a diagonal matrix of allele count information for all variants

n_ind

total number of individuals in the population

Examples

Run this code
af_mat <- get_af_mat(AC = c(20, 50, 10, 1, 5), n_ind = 10000)

Run the code above in your browser using DataLab